UserSession class

Annotations

Constructors

UserSession({required String accessToken, required String idToken, required String refreshToken, required Map<String, dynamic> accessTokenClaims, required Map<String, dynamic> idTokenClaims, required DateTime accessTokenExpiry, required DateTime idTokenExpiry})
const

Properties

accessToken String
final
accessTokenClaims Map<String, dynamic>
final
accessTokenExpiry DateTime
final
hashCode int
The hash code for this object.
no setterinherited
idToken String
final
idTokenClaims Map<String, dynamic>
final
idTokenExpiry DateTime
final
refreshToken String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) UserSession